@@ -10,7 +10,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -269,9 +269,9 @@
 {
   BOOL result = NO;
   NSString *classNameCopy = [NSString stringWithString: className];
-  NSString *superClassNameCopy = [NSString stringWithString: superClassName];
-  NSMutableArray *actionsCopy = [NSMutableArray arrayWithArray: actions];
-  NSMutableArray *outletsCopy = [NSMutableArray arrayWithArray: outlets];
+  NSString *superClassNameCopy = (superClassName != nil)?[NSString stringWithString: superClassName]:nil;
+  NSMutableArray *actionsCopy = (actions != nil)?[NSMutableArray arrayWithArray: actions]:[NSMutableArray array];
+  NSMutableArray *outletsCopy = (outlets != nil)?[NSMutableArray arrayWithArray: outlets]:[NSMutableArray array];
 
   // We make an autoreleased copy of all of the inputs.  This prevents changes
   // to the original objects from reflecting here. GJC
@@ -299,7 +299,10 @@
 	  
 	  [classInfo setObject: outletsCopy forKey: @"Outlets"];
 	  [classInfo setObject: actionsCopy forKey: @"Actions"];
-	  [classInfo setObject: superClassNameCopy forKey: @"Super"];
+	  if(superClassNameCopy != nil)
+	    {
+	      [classInfo setObject: superClassNameCopy forKey: @"Super"];
+	    }
 	  [classInformation setObject: classInfo forKey: classNameCopy];
 	  
 	  // if it's a custom class add it to the list.
@@ -947,6 +950,20 @@
   return [self classInfoForClassName: className];
 }
 
+- (BOOL) actionExists: (NSString *)action
+	 onClassNamed: (NSString *)className
+{
+  NSArray *actions = [self allActionsForClassNamed: className];
+  return [actions containsObject: action];
+}
+
+- (BOOL) outletExists: (NSString *)outlet
+	 onClassNamed: (NSString *)className
+{
+  NSArray *outlets = [self allOutletsForClassNamed: className];
+  return [outlets containsObject: outlet];
+}
+
 - (void) dealloc
 {
   RELEASE(classInformation);
@@ -998,7 +1015,7 @@
 	referenceClassList: [classInformation allKeys]
 	intoArray: array];
 
-  return array;
+  return [array sortedArrayUsingSelector: @selector(caseInsensitiveCompare:)];
 }
 
 - (NSArray *) allCustomSubclassesOf: (NSString *)superClass
@@ -1009,7 +1026,7 @@
 	referenceClassList: customClasses
 	intoArray: array];
 
-  return array;
+  return [array sortedArrayUsingSelector: @selector(caseInsensitiveCompare:)];
 }
 
 - (NSArray *) customSubClassesOf: (NSString *)superclass
@@ -1049,7 +1066,7 @@
 	}
     }
       
-  return subclasses;
+  return [subclasses sortedArrayUsingSelector: @selector(caseInsensitiveCompare:)];
 }
 
 - (void) removeClassNamed: (NSString *)className
@@ -1878,14 +1895,26 @@
 		    }
 		}
 	      
-	      if([self isKnownClass: superClass] && 
-		 [cls isCategory] == NO &&
-		 superClass != nil)
+	      if(([self isKnownClass: superClass] || superClass == nil) && 
+		 [cls isCategory] == NO)
 		{
 		  if([self isKnownClass: className])
 		    {
-		      if([document removeConnectionsForClassNamed: className])
+		      NSString *title = [NSString stringWithFormat: 
+						    _(@"Reparsing Class")];
+		      NSString *msg = [NSString stringWithFormat: 
+						  _(@"This may break connections to "
+						    @"actions/outlets to instances of class '%@' "
+						    @"and it's subclasses.  Continue?"), 
+						className];
+		      int retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
+
+		      if (retval == NSAlertDefaultReturn)
 			{
+			  // get the owner and reset the class name to NSApplication.
+			  GormFilesOwner *owner = [document objectForName: @"NSOwner"];
+			  NSString *ownerClassName = [owner className];
+
 			  // delete the class..
 			  [self removeClassNamed: className];
 			  
@@ -1894,6 +1923,12 @@
 				withSuperClassNamed: superClass
 				withActions: actions
 				withOutlets: outlets];
+			  
+			  // refresh the connections.
+			  [document refreshConnectionsForClassNamed: className];
+
+			  // reset the class name.
+			  [owner setClassName: ownerClassName];
 			}
 		    }
 		  else
@@ -1908,7 +1943,7 @@
 		{
 		  [self addActions: actions forClassNamed: className];
 		}
-	      else if(superClass != nil)
+	      else if(superClass != nil && [self isKnownClass: superClass] == NO)
 		{
 		  result = NO;
 		  [NSException raise: NSGenericException
@@ -2044,6 +2079,7 @@
 - (NSArray *) allSuperClassesOf: (NSString *)className
 {
   NSMutableArray *classes = [NSMutableArray array];
+
   while (![self isRootClass: className] && className != nil)
     {
       NSDictionary *dict = [self classInfoForClassName: className];
@@ -2061,7 +2097,8 @@
 	  break;
 	}
     }
-  return classes;
+
+  return classes; 
 }
 
 - (void) addActions: (NSArray *)actions forClassNamed: (NSString *)className
@@ -2162,6 +2199,39 @@
   return YES;
 }
 
+- (NSString *) findClassByName: (NSString *)name
+{
+  NSArray *classNames = [self allClassNames];
+  NSEnumerator *en = [classNames objectEnumerator];
+  NSString *className = nil;
+  int namelen = [name length];
+
+  while((className = [en nextObject]) != nil)
+    {
+      int classlen = [className length];
+      if(namelen < classlen)
+	{
+	  NSComparisonResult result = 
+	    [className compare: name
+		       options: NSCaseInsensitiveSearch
+		       range: ((NSRange){0, namelen})];
+	  if(result == NSOrderedSame)
+	    {
+	      break;
+	    }
+	}
+      else if(namelen == classlen)
+	{
+	  if([className caseInsensitiveCompare: name] == NSOrderedSame)
+	    {
+	      break;
+	    }
+	} 
+    }
+
+  return className;
+}
+
 - (NSString *) description
 {
   return [NSString stringWithFormat: @"<%s: %lx> = %@",
