@@ -36,14 +36,71 @@
 #include <GormCore/GormFunctions.h>
 
 @interface GormGormWrapperLoader : GormWrapperLoader
+{
+  NSMutableArray *_repairLog;
+  id message;
+  id textField;
+  id panel;
+}
 @end
 
+@interface NSWindow (Level)
+- (int) windowLevel;
+@end;
+
+@implementation NSWindow (Level)
+- (int) windowLevel
+{
+  return _windowLevel;
+}
+@end;
+
 @implementation GormGormWrapperLoader
 + (NSString *) type
 {
   return @"GSGormFileType";
 }
 
+- (id) init
+{
+  if((self = [super init]) != nil)
+    {
+      _repairLog = [[NSMutableArray alloc] init];
+    }
+  return self;
+}
+
+- (void) dealloc
+{
+  RELEASE(_repairLog);
+  [super dealloc];
+}
+
+- (void) _openMessagePanel: (NSString *) msg
+{
+  NSEnumerator *en = [_repairLog objectEnumerator];
+  id m = nil;
+
+  if([NSBundle loadNibNamed: @"GormInconsistenciesPanel"
+	       owner: self] == NO)
+    {
+      NSLog(@"Failed to open message panel...");
+    }
+  else
+    {
+      [message setStringValue: msg];
+      
+      while((m = [en nextObject]) != nil)
+	{
+	  [textField insertText: m];
+	}
+
+      [panel orderFront: self];
+    }
+
+  [_repairLog removeAllObjects];
+}
+
 /** 
  * The sole purpose of this method is to clean up .gorm files from older
  * versions of Gorm which might have some dangling references.   This method
@@ -56,22 +113,33 @@
   NSString *key = nil;
   int errorCount = 0;
   NSString *errorMsg = nil;
+  NSArray *connections = [document allConnectors];
+  id con = nil;
 
   NSRunAlertPanel(_(@"Warning"), 
 		  _(@"You are running with 'GormRepairFileOnLoad' set to YES."),
 		  nil, nil, nil);
 
+  /**
+   * Iterate over all objects in nameTable.
+   */
+  [document deactivateEditors];
   while((key = [en nextObject]) != nil)
   {
     id obj = [[document nameTable] objectForKey: key];
 
+    /*
+     * Take care of any dangling menus...
+     */
     if([obj isKindOfClass: [NSMenu class]] && ![key isEqual: @"NSMenu"])
       {
 	id sm = [obj supermenu];
 	if(sm == nil)
 	  {
 	    NSArray *menus = findAll(obj);
-	    NSLog(@"Found and removed a dangling menu %@, %@.",obj,[document nameForObject: obj]);
+	    [_repairLog addObject: 
+			  [NSString stringWithFormat: @"ERROR ==> Found and removed a dangling menu %@, %@.\n",
+				    obj, key]];
 	    [document detachObjects: menus];
 	    [document detachObject: obj];
 	    
@@ -85,6 +153,10 @@
 	  }
       }
 
+    /*
+     * Take care of any dangling menu items...
+     */
+    /*
     if([obj isKindOfClass: [NSMenuItem class]])
       {
 	id m = [obj menu];
@@ -92,7 +164,9 @@
 	  {
 	    id sm = [obj submenu];
 
-	    NSLog(@"Found and removed a dangling menu item %@, %@.",obj,[document nameForObject: obj]);
+	    [_repairLog addObject:
+			  [NSString stringWithFormat: @"ERROR ==> Found and removed an unattached menu item %@, %@.\n",
+				    obj, key]];
 	    [document detachObject: obj];
 
 	    // if there are any submenus, detach those as well.
@@ -104,26 +178,9 @@
 	    errorCount++;
 	  }
       }
-
-    /**
-     * If it's a view and it does't have a window *AND* it's not a top level object
-     * then it's not a standalone view, it's an orphan.   Delete it.
-     *
-    if([obj isKindOfClass: [NSView class]])
-      {
-	if([obj window] == nil && 
-	   [[document topLevelObjects] containsObject: obj] == NO &&
-	   [obj hasSuperviewKindOfClass: [NSTabView class]] == NO)
-	  {
-	    NSLog(@"Found and removed an orphan view %@, %@",obj,[document nameForObject: obj]);
-	    [document detachObject: obj];
-	    [obj removeFromSuperview];
-	    errorCount++;
-	  }
-      }
     */
 
-    /**
+    /*
      * If there is a view which is not associated with a name, give it one...
      */
     if([obj isKindOfClass: [NSWindow class]])
@@ -131,32 +188,124 @@
 	NSArray *allViews = allSubviews([obj contentView]);
 	NSEnumerator *ven = [allViews objectEnumerator];
 	id v = nil;
+
+	if([obj windowLevel] != NSNormalWindowLevel)
+	  {
+	    [obj setLevel: NSNormalWindowLevel];
+	    [_repairLog addObject: 
+			  [NSString stringWithFormat: 
+				      @"ERROR ==> Found window %@ with an invalid level, correcting.\n", 
+				    obj]];
+	    errorCount++;
+	  }
 	
 	while((v = [ven nextObject]) != nil)
 	  {
-	    if([document nameForObject: v] == nil)
+	    NSString *name = nil;
+
+	    // skip these...
+	    if([v isKindOfClass: [NSMatrix class]])
+	      {
+		[_repairLog addObject: @"INFO: Skipping NSMatrix view.\n"];
+		continue;
+	      }
+	    else if([v isKindOfClass: [NSScroller class]] &&
+		    [[v superview] isKindOfClass: [NSTextView class]])
+	      {
+		[_repairLog addObject: @"INFO: Skipping NSScroller in an NSTextView.\n"];
+		continue;
+	      }
+	    else if([v isKindOfClass: [NSScroller class]] &&
+		    [[v superview] isKindOfClass: [NSBrowser class]])
+	      {
+		[_repairLog addObject: @"INFO: Skipping NSScroller in an NSTextView.\n"];
+		continue;
+	      }
+	    else if([v isKindOfClass: [NSClipView class]] &&
+		    [[v superview] isKindOfClass: [NSTextView class]])
+	      {
+		[_repairLog addObject: @"INFO: Skipping NSClipView in an NSTextView.\n"];
+		continue;
+	      }
+	    else if([v isKindOfClass: [NSClipView class]] &&
+		    [[v superview] isKindOfClass: [NSBrowser class]])
+	      {
+		[_repairLog addObject: @"INFO: Skipping NSClipView in an NSTextView.\n"];
+		continue;
+	      }
+	       	    
+	    if((name = [document nameForObject: v]) == nil)
 	      {
-		NSString *name = nil;
 		[document attachObject: v toParent: [v superview]];
 		name = [document nameForObject: v];
-		NSLog(@"Found view %@ without an associated name, adding to the nametable as %@", v, name);
+		[_repairLog addObject: 
+			      [NSString stringWithFormat: 
+					  @"ERROR ==> Found view %@ without an associated name, adding to the nametable as %@\n", 
+					v, name]];
 		if([v respondsToSelector: @selector(stringValue)])
 		  {
-		    NSLog(@"View string value is %@",[v stringValue]);
+		    [_repairLog addObject: [NSString stringWithFormat: @"INFO: View string value is %@\n",[v stringValue]]];
 		  }
 		errorCount++;
 	      }
+	    [_repairLog addObject: [NSString stringWithFormat: @"INFO: Checking view %@ with name %@\n", v, name]];
 	  }
       }
   }
-
+  [document reactivateEditors];
+  
+  /**
+   * Iterate over all connections...  remove connections with nil sources.
+   */
+  en = [connections objectEnumerator];
+  while((con = [en nextObject]) != nil)
+    {
+      id src = [con source];
+      id dst = [con destination];
+      if([con isKindOfClass: [NSNibConnector class]])
+	{
+	  if(src == nil)
+	    {
+	      [_repairLog addObject: 
+			    [NSString stringWithFormat: @"ERROR ==> Removing bad connector with nil source: %@\n",con]];
+	      [document removeConnector: con];
+	      errorCount++;
+	    }
+	  else if([src isKindOfClass: [NSString class]])
+	    {
+	      id obj = [document objectForName: src];
+	      if(obj == nil)
+		{
+		  [_repairLog addObject: 
+				[NSString stringWithFormat: 
+					    @"ERROR ==> Removing bad connector with source that is not in the nametable: %@\n",
+					  con]];
+		  [document removeConnector: con];
+		  errorCount++;
+		}
+	    }
+	  else if([dst isKindOfClass: [NSString class]])
+	    {
+	      id obj = [document objectForName: dst];
+	      if(obj == nil)
+		{
+		  [_repairLog addObject: 
+				[NSString stringWithFormat: 
+					    @"ERROR ==> Removing bad connector with destination that is not in the nametable: %@\n",
+					  con]];
+		  [document removeConnector: con];
+		  errorCount++;
+		}
+	    }
+	}
+    }
+  
   // report the number of errors...
   if(errorCount > 0)
     {
       errorMsg = [NSString stringWithFormat: @"%d inconsistencies were found, please save the file.",errorCount]; 
-      NSRunAlertPanel(_(@"Warning"), 
-		      errorMsg,
-		      nil, nil, nil); 
+      [self _openMessagePanel: errorMsg];
+      [document touch];
     }
 }
 
@@ -196,6 +345,16 @@
       NSString                  *subClassName = nil;
       unsigned int           	version = NSNotFound;
       NSDictionary              *fileWrappers = nil;
+      GSNibContainer            *container;
+      NSArray                   *visible;
+      NSArray                   *deferred;
+      GormFilesOwner            *filesOwner;
+      GormFirstResponder        *firstResponder;
+      NSArray                   *objs;
+      NSMutableArray            *connections;
+      NSDictionary              *nt;
+      id                        visObj;
+      id                        defObj;
 
       if ([super loadFileWrapper: wrapper withDocument: doc])
 	{
@@ -270,7 +429,7 @@
 	  
 	  // turn off custom classes.
 	  [GSClassSwapper setIsInInterfaceBuilder: YES]; 
-	  GSNibContainer *container = [u decodeObject];
+	  container = [u decodeObject];
 	  if (container == nil || [container isKindOfClass: [GSNibContainer class]] == NO)
 	    {
 	      return NO;
@@ -288,8 +447,8 @@
 	  //
 	  // Get all of the visible objects...
 	  //
-	  NSArray *visible = [container visibleWindows];
-	  id visObj = nil;
+	  visible = [container visibleWindows];
+	  visObj = nil;
 	  enumerator = [visible objectEnumerator];
 	  while((visObj = [enumerator nextObject]) != nil)
 	    {
@@ -299,8 +458,8 @@
 	  //
 	  // Get all of the deferred objects...
 	  //
-	  NSArray *deferred = [container deferredWindows];
-	  id defObj = nil;
+	  deferred = [container deferredWindows];
+	  defObj = nil;
 	  enumerator = [deferred objectEnumerator];
 	  while((defObj = [enumerator nextObject]) != nil)
 	    {
@@ -312,8 +471,8 @@
 	   * to hold the objects rather than their names (using our own dummy
 	   * object as the 'NSOwner'.
 	   */
-	  GormFilesOwner *filesOwner = [document filesOwner];
-	  GormFirstResponder *firstResponder = [document firstResponder];
+	  filesOwner = [document filesOwner];
+	  firstResponder = [document firstResponder];
 	  ownerClass = [[container nameTable] objectForKey: @"NSOwner"];
 	  if (ownerClass)
 	    {
@@ -332,17 +491,17 @@
 	  //
 	  // Add top level items...
 	  //
-	  NSArray *objs = [[container topLevelObjects] allObjects];
+	  objs = [[container topLevelObjects] allObjects];
 	  [[document topLevelObjects] addObjectsFromArray: objs];
 					
 	  //
 	  // Add connections
 	  //
-	  NSMutableArray *connections = [document connections];
+	  connections = [document connections];
 	  [connections addObjectsFromArray: [container connections]];
 
 	  /* Iterate over the contents of nameTable and create the connections */
-	  NSDictionary *nt = [document nameTable];
+	  nt = [document nameTable];
 	  enumerator = [connections objectEnumerator];
 	  while ((con = [enumerator nextObject]) != nil)
 	    {
