@@ -98,8 +98,20 @@
 		}
 
 	      NSMapInsert(_objects, src, dst);
+	      if(dst == nil)
+		{
+		  NSLog(@"==> WARNING: value for object %@ is %@ in objects map.",src,dst);
+		}
 	      NSMapInsert(_names, src, name);
+	      if(dst == nil)
+		{
+		  NSLog(@"==> WARNING: value for object %@ is %@ in names map.",src,dst);
+		}
 	      NSMapInsert(_oids, src, currOid);
+	      if(dst == nil)
+		{
+		  NSLog(@"==> WARNING: value for object %@ is %@ in oids map.",src,dst);
+		}
 	    }
 	  else
 	    {
