@@ -83,25 +83,30 @@
       NSData		        *data = nil;
       NSData                    *classes = nil;
       NSKeyedUnarchiver		*u = nil;
-      NSEnumerator		*enumerator = nil;
       NSString                  *key = nil;
       GormPalettesManager       *palettesManager = [(id<Gorm>)NSApp palettesManager];
       NSDictionary              *substituteClasses = [palettesManager substituteClasses];
-      NSEnumerator              *en = [substituteClasses keyEnumerator];
       NSString                  *subClassName = nil;
       NSDictionary              *fileWrappers = nil;
 
       if ([super loadFileWrapper: wrapper withDocument: doc])
 	{
 	  GormClassManager *classManager = [document classManager];
+	  id               docFilesOwner;
+	  NSMapTable       objects;
+	  NSArray          *objs;
+	  NSEnumerator     *en;
+	  id               o;
+	  NSMapTable       *classesTable;
+	  NSArray          *classKeys;
 
 	  key = nil;
 	  fileWrappers = [wrapper fileWrappers];
 	  
 	  // turn off custom classes...
 	  [NSClassSwapper setIsInInterfaceBuilder: YES];	  
-	  enumerator = [fileWrappers keyEnumerator];
-	  while((key = [enumerator nextObject]) != nil)
+	  en = [fileWrappers keyEnumerator];
+	  while((key = [en nextObject]) != nil)
 	    {
 	      NSFileWrapper *fw = [fileWrappers objectForKey: key];
 	      if([fw isRegularFile])
@@ -152,6 +157,7 @@
 	  /*
 	   * Substitute any classes specified by the palettes...
 	   */
+	  en = [substituteClasses keyEnumerator];
 	  while((subClassName = [en nextObject]) != nil)
 	    {
 	      NSString *realClassName = [substituteClasses objectForKey: subClassName];
@@ -170,11 +176,11 @@
 	    }
 	  nibFilesOwner = [container objectForName: @"File's Owner"];
 
-	  id docFilesOwner = [document filesOwner];
-	  NSMapTable objects = [container names];
-	  NSArray *objs = NSAllMapTableKeys(objects);
-	  NSEnumerator *en = [objs objectEnumerator];
-	  id o = nil;
+	  docFilesOwner = [document filesOwner];
+	  objects = [container names];
+	  objs = NSAllMapTableKeys(objects);
+	  en = [objs objectEnumerator];
+	  o = nil;
 
 	  //
 	  // set the current class on the File's owner...
@@ -233,13 +239,13 @@
 	  //
 	  // Add custom classes...
 	  //
-	  NSMapTable *classes = [container classes];
-	  NSArray *classKeys = NSAllMapTableKeys(classes);
+	  classesTable = [container classes];
+	  classKeys = NSAllMapTableKeys(classesTable);
 	  en = [classKeys objectEnumerator];
 	  while((o = [en nextObject]) != nil)
 	    {
 	      NSString *name = [document nameForObject: o];
-	      NSString *customClass = NSMapGet(classes, o);
+	      NSString *customClass = NSMapGet(classesTable, o);
 	      if(name != nil && customClass != nil)
 		{
 		  [classManager setCustomClass: customClass forName: name];
@@ -259,19 +265,12 @@
 	    {
 	      id dest = [o destination];
 	      id src = [o source];
+
+	      // NSLog(@"Connector: %@",o);
+
 	      if([o isKindOfClass: [NSNibControlConnector class]])
 		{
 		  NSString *tag = [o label];
-		  if(dest == nibFilesOwner)
-		    {
-		      [o setDestination: [document filesOwner]];
-		    }
-		  else if(dest == nil)
-		    {
-		      [o setDestination: [document firstResponder]];
-		    }
-
-		  // Correct the missing colon problem...
 		  NSRange colonRange = [tag rangeOfString: @":"];
 		  unsigned int location = colonRange.location;
 		  
@@ -282,19 +281,37 @@
 		    }
 		}
 
+	      if(dest == nibFilesOwner)
+		{
+		  [o setDestination: [document filesOwner]];
+		}
+	      else if(dest == nil)
+		{
+		  [o setDestination: [document firstResponder]];
+		}
+
+	      if(src == nibFilesOwner)
+		{
+		  [o setSource: [document filesOwner]];
+		}
+	      else if(src == nil)
+		{
+		  [o setSource: [document firstResponder]];
+		}
+
 	      // check src/dest for window template...
 	      if([src isKindOfClass: [NSWindowTemplate class]])
 		{
 		  id win = [src realObject];
 		  [o setSource: win];
 		}
-	      else if([dest isKindOfClass: [NSWindowTemplate class]])
+
+	      if([dest isKindOfClass: [NSWindowTemplate class]])
 		{
 		  id win = [dest realObject];
 		  [o setDestination: win];
 		}
 
-
 	      // skip any help connectors...
 	      if([o isKindOfClass: [NSIBHelpConnector class]])
 		{
@@ -335,12 +352,14 @@
   if([obj isKindOfClass: [NSWindowTemplate class]])
     {
       GormClassManager *classManager = [document classManager];
+      Class clz ;
       NSString *className = [obj className];
+      
       if([classManager isCustomClass: className])
 	{
 	  className = [classManager nonCustomSuperClassOf: className];
 	}
-      Class clz = [unarchiver classForClassName: className];
+      clz = [unarchiver classForClassName: className];
       [obj setBaseWindowClass: clz];
     }
   else if([obj respondsToSelector: @selector(setTarget:)] &&
