@@ -11,7 +11,7 @@
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
@@ -66,7 +66,37 @@
 - (void) ok: (id)sender
 {
   if (sender == typeMatrix)
-      [object setTabViewType:[[sender selectedCell] tag]];
+    {
+      unsigned int type = 0;
+
+      switch([[sender selectedCell] tag])
+        {
+	  case 0:
+	    type = NSTopTabsBezelBorder;
+	    break;
+	  case 5:
+	    type = NSLeftTabsBezelBorder;
+	    break;
+	  case 1:
+	    type = NSBottomTabsBezelBorder;
+	    break;
+	  case 6:
+	    type = NSRightTabsBezelBorder;
+	    break;
+	  case 2:
+	    type = NSNoTabsBezelBorder;
+	    break;
+	  case 3:
+	    type = NSNoTabsLineBorder;
+	    break;
+	  case 4:
+	    type = NSNoTabsNoBorder;
+	    break;
+	  default:
+	    break;
+	}
+      [object setTabViewType: type];
+    }
   else if (sender == allowtruncate)
     {
       BOOL flag;
